==> dodfminer-1.3.6.tar.gz: dodfminer-1.3.6/README.md <==
[<img src="docs/source/_static/knedle.svg" width="1300" title="">](https://unb-knedle.github.io/)

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Maintainability](https://api.codeclimate.com/v1/badges/a8ab63922f34a63be4cb/maintainability)](https://codeclimate.com/github/UnB-KnEDLe/DODFMiner/maintainability)
[![Documentation Status](https://readthedocs.org/projects/dodfminer/badge/?version=latest)](https://dodfminer.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/UnB-KnEDLe/DODFMiner/badge.svg)](https://coveralls.io/github/UnB-KnEDLe/DODFMiner)

### DODFMiner

DODFMiner is the software that is being developed for the extraction of data from documents in PDF format referring to the publications of the Official Gazette of the Federal District, Brazil.


### Contribute

If you want to contribute to our project, it's simple! We have a [Contribution Guide](CONTRIBUTING.md) where all the steps to contribute are explained.
Don't forget to also read our [Code of Conduct](CODE_OF_CONDUCT.md).
If you have any questions you can also contact us by creating an issue or by ask.knedle@googlegroups.com

### Installation

To run the project environment, access our [installation guide](https://dodfminer.readthedocs.io/en/stable/user/install.html).

### Documentation

To access our documentation and understand how to install and use the library, [Read The Docs](https://dodfminer.readthedocs.io).

### Collaborators

The information of [collaborators](https://unb-knedle.github.io/#members) can be accessed on our page.

==> dodfminer-1.3.11.tar.gz: dodfminer-1.3.11/README.md <==
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Maintainability](https://api.codeclimate.com/v1/badges/a8ab63922f34a63be4cb/maintainability)](https://codeclimate.com/github/UnB-KnEDLe/DODFMiner/maintainability)
[![Documentation Status](https://readthedocs.org/projects/dodfminer/badge/?version=latest)](https://dodfminer.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/UnB-KnEDLe/DODFMiner/badge.svg)](https://coveralls.io/github/UnB-KnEDLe/DODFMiner)

### DODFMiner

DODFMiner is the software that is being developed for the extraction of data from documents in PDF format referring to the publications of the Official Gazette of the Federal District, Brazil.


### Contribute

If you want to contribute to our project, it's simple! We have a [Contribution Guide](CONTRIBUTING.md) where all the steps to contribute are explained.
Don't forget to also read our [Code of Conduct](CODE_OF_CONDUCT.md).
If you have any questions you can also contact us by creating an issue or by ask.knedle@googlegroups.com

### Installation

To run the project environment, access our [installation guide](https://dodfminer.readthedocs.io/en/main/user/install.html).

### Documentation

To access our documentation and understand how to install and use the library, [Read The Docs](https://dodfminer.readthedocs.io).

### Collaborators

The information of [collaborators](https://unb-knedle.github.io/#members) can be accessed on our page.
